@@ -29,8 +29,8 @@
 #include <KPluginFactory>
 #include <KXMLGUIClient>
 
-#include <QtCore/QList>
-#include <QtCore/QObject>
+#include <QList>
+#include <QObject>
 
 class KAboutData;
 class QAction;
@@ -90,7 +90,7 @@ public:
      *       It's ok to have several plugins using the same application name.
      * @param pluginName The unique name of the plugin. Defaults to appName if not set.
      */
-    Plugin(Core *core, QObject *parent, const char *appName, const char *pluginName = 0);
+    Plugin(Core *core, QObject *parent, const char *appName, const char *pluginName = nullptr);
 
     /**
      * Destroys the plugin.
@@ -176,13 +176,6 @@ public:
      */
     KParts::ReadOnlyPart *part();
 
-    /**
-     * Reimplement this method and return the a path relative to "data" to the tips file.
-     * The tips file contains hints/tips that are displayed at the beginning of the program
-     * as "tip of the day". It has nothing to do with tooltips.
-     */
-    virtual QString tipFile() const;
-
     /**
      * This function is called when the plugin is selected by the user before the
      * widget of the KPart belonging to the plugin is raised.
@@ -330,7 +323,7 @@ protected:
     /**
      * Virtual hook for BC extension.
      */
-    virtual void virtual_hook(int id, void *data);
+    void virtual_hook(int id, void *data) override;
 
 private:
     //@cond PRIVATE
